==> ginkgocadx_2.8.0.4602.orig.tar.gz: ginkgocadx-2.8.0.4602/src/cadxcore/main/licencia.h <==
/*
 *
 *  $Id: licencia.h 4602 2012-01-26 07:23:02Z tovar $
 *  Ginkgo CADx Project
 *
 *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
 *  http://ginkgo-cadx.com
 *
 *  This file is licensed under LGPL v3 license.
 *  See License.txt for details
 *
 *
 */
#pragma once
#include <string>

#if !defined(GINKGO_VERSION)
	#define GINKGO_VERSION     2
#endif
#if !defined(GINKGO_SUB_VERSION)
	#define GINKGO_SUB_VERSION 8
#endif
#if !defined(GINKGO_SUB_RELEASE)
	#define GINKGO_SUB_RELEASE 0
#endif

#define GINKGO_BUILD           "$Revision: 4602 $"

#if !defined(GINKGO_CODENAME)
	#define GINKGO_CODENAME    "final"
#endif
#define GINKGO_COPYRIGHT   "© 2012"

#if !defined(INTERNET_DIST)
#include "private_dist.h"
#endif

//
// Permisos completos
// "<?xml version=\"1.0\"?>\n"
// "<permisos>\n"
// "<permiso namespace=\"core\" id=\"default\" accion=\"activar\"/>"
// "<permiso namespace=\"core.pacs.limits\" id=\"pacs\" accion=\"desactivar\"/>"
// "<permiso namespace=\"core.pacs.limits\" id=\"pacs_upload\" accion=\"activar\"/>"
// "<permiso namespace=\"core.menu\" id=\"configuracion\" accion=\"desactivar\"/>"
// "<permiso namespace=\"core.menu\" id=\"filtrado\" accion=\"activar\"/>"
// "<permiso namespace=\"atencionprimaria\" id=\"dicomizador\" accion=\"activar\"/>"
// "<permiso namespace=\"atencionprimaria\" id=\"vista2d\" accion=\"activar\"/>"
// "<permiso namespace=\"atencionprimaria\" id=\"vistasac\" accion=\"activar\"/>"
// "<permiso namespace=\"atencionprimaria.vistasimple\" id=\"guardar cambios\" accion=\"desactivar\"/>"
// "<permiso namespace=\"oftalmologia\" id=\"dicomizador\" accion=\"activar\"/>"
// "<permiso namespace=\"oftalmologia\" id=\"vistaoftal\" accion=\"activar\"/>"
// "<permiso namespace=\"oftalmologia.vistaoftal\" id=\"Marcado del arbol de venas\" accion=\"activar\"/>"
// "<permiso namespace=\"oftalmologia.vistaoftal\" id=\"Marcado de Oftalmologia\" accion=\"activar\"/>"
// "<permiso namespace=\"oftalmologia.vistaoftal\" id=\"CoreMarcado\" accion=\"activar\"/>"
// "<permiso namespace=\"oftalmologia.vistaoftal\" id=\"Pegado de imagenes de la serie\" accion=\"desactivar\"/>"
// "<permiso namespace=\"oftalmologia.vistaoftal\" id=\"CoreAnotacion\" accion=\"activar\"/>"
// "<permiso namespace=\"oftalmologia.vistaoftal\" id=\"CoreElevacion\" accion=\"desactivar\"/>"
// "<permiso namespace=\"oftalmologia.vistaoftal\" id=\"CoreVarita\" accion=\"desactivar\"/>"
// "<permiso namespace=\"oftalmologia.vistaoftal\" id=\"panel de herramientas\" accion=\"desactivar\"/>"
// "<permiso namespace=\"oftalmologia.vistaoftal\" id=\"guardar cambios\" accion=\"desactivar\"/>"
// "<permiso namespace=\"dermatologia\" id=\"dicomizador\" accion=\"activar\"/>"
// "<permiso namespace=\"dermatologia\" id=\"vistapasi\" accion=\"activar\"/>"
// "<permiso namespace=\"dermatologia.vistapasi\" id=\"CoreMarcado\" accion=\"desactivar\"/>"
// "<permiso namespace=\"dermatologia.vistapasi\" id=\"DermaAnonimizacion\" accion=\"desactivar\"/>"
// "<permiso namespace=\"dermatologia.vistapasi\" id=\"CoreNota\" accion=\"desactivar\"/>"
// "<permiso namespace=\"dermatologia.vistapasi\" id=\"CoreElevacion\" accion=\"desactivar\"/>"
// "<permiso namespace=\"dermatologia.vistapasi\" id=\"CoreVarita\" accion=\"desactivar\"/>"
// "<permiso namespace=\"dermatologia.vistapasi\" id=\"panel de herramientas pasi\" accion=\"activar\"/>"
// "<permiso namespace=\"dermatologia.vistapasi\" id=\"guardar cambios\" accion=\"desactivar\"/>"
// "</permisos>\n"

#ifdef INTERNET_DIST
    #define GINKGO_REGISTERED_USER _Std("Evaluation")
    #define GINKGO_REGISTERED_ORGANIZATION "MetaEmotion"
    #define GINKGO_EXPIRATION_DAYS 0 // <=0 Deshabilitado. > 0 Días restantes desde la fecha de la compilación.
    #define GINKGO_MENSAJE_LICENCIA "This is a open source Ginkgo CADx Framework build. MetaEmotion S.L does not provide support so eximes from all responsabilities derived from its usage.\n\nWARRANTY DISCLAIMER\n\n" \
	"The software, procedures, information and data made available by MetaEmotion S.L. under current conditions are provided \"AS IS\", without warranties of any kind except for contracted services, in which cases the specific contract conditions will be applied.\n" \
	"MetaEmotion S.L. expressly disclaims any representations and warranties, including without limitation, the implied warranties of merchantability and fitness for a particular purpose.\n\n" \
	"MetaEmotion S.L. shall have no liability for:\n" \
    " * Any loss or injury caused, in whole or in part, by its actions, omissions, or negligence, or for contingencies beyond its control, in procuring, compiling, or delivering the Information or\n" \
    " * Any errors, omissions, or inaccuracies in the Information regardless of how caused, or delays or interruptions in delivery of the Information; or\n" \
	" * Any decision made or action taken or not taken in reliance upon the Information furnished hereunder.\n\n" \
	"Under no circumstances shall the authors be liable for direct, indirect, special, incidental, consequential damages or misdiagnosis\n" \
    "resulting from the use, misuse, or inability to use the software, even if the authors have been advised of the possibility of such damages.\n" \
	"This software musn't be sold without prior approval of the authors.\n" \
	"\nThe user assumes the entire risk of using this program as well as conditions above."\
	"\nGinkgo CADx is licensed under the LGPL v3 license. You can find the legal terms of the license at http://www.gnu.org/copyleft/lgpl.html"
	//#define _GINKGO_DERMA
	//#define _GINKGO_OFTAL
    #define _GINKGO_ATENCION_PRIMARIA

    #define PERMISOS_DIST "<?xml version=\"1.0\"?>\n"\
		"<permisos>\n" \
		"<permiso namespace=\"core\" id=\"default\" accion=\"activar\"/>" \
		"<permiso namespace=\"oftalmologia.vistaoftal\" id=\"panel de herramientas\" accion=\"desactivar\"/>" \
		"<permiso namespace=\"core.menu\" id=\"filtrado\" accion=\"desactivar\"/>" \
		"<permiso namespace=\"core.menu\" id=\"licencia\" accion=\"desactivar\" activopordefecto=\"true\" valorpordefecto=\"\" valor=\"\" />" \
		"</permisos>\n"

#endif

==> ginkgocadx_2.12.0.4889.orig.tar.gz: ginkgocadx-2.12.0.4889/src/cadxcore/main/licencia.h <==
/*
 *
 *  $Id: licencia.h 4889 2012-04-20 06:37:09Z carlos $
 *  Ginkgo CADx Project
 *
 *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
 *  http://ginkgo-cadx.com
 *
 *  This file is licensed under LGPL v3 license.
 *  See License.txt for details
 *
 *
 */
#pragma once
#include <string>

#if !defined(GINKGO_VERSION)
	#define GINKGO_VERSION     2
#endif
#if !defined(GINKGO_SUB_VERSION)
	#define GINKGO_SUB_VERSION 12
#endif
#if !defined(GINKGO_SUB_RELEASE)
	#define GINKGO_SUB_RELEASE 0
#endif

#define GINKGO_BUILD           "$Revision: 4889 $"

#if !defined(GINKGO_CODENAME)
	#define GINKGO_CODENAME    "final"
#endif
#define GINKGO_COPYRIGHT   "© 2012"

#define INC 25 // Update rev
//
//
// Permisos completos
// "<?xml version=\"1.0\"?>\n"
// "<permisos>\n"
// "<permiso namespace=\"core\" id=\"default\" accion=\"activar\"/>"
// "<permiso namespace=\"core.pacs.limits\" id=\"pacs\" accion=\"desactivar\"/>"
// "<permiso namespace=\"core.pacs.limits\" id=\"pacs_upload\" accion=\"activar\"/>"
// "<permiso namespace=\"core.menu\" id=\"configuracion\" accion=\"desactivar\"/>"
// "<permiso namespace=\"core.menu\" id=\"filtrado\" accion=\"activar\"/>"
// "<permiso namespace=\"atencionprimaria\" id=\"dicomizador\" accion=\"activar\"/>"
// "<permiso namespace=\"atencionprimaria\" id=\"vista2d\" accion=\"activar\"/>"
// "<permiso namespace=\"atencionprimaria\" id=\"vistasac\" accion=\"activar\"/>"
// "<permiso namespace=\"atencionprimaria.vistasimple\" id=\"guardar cambios\" accion=\"desactivar\"/>"
// "<permiso namespace=\"oftalmologia\" id=\"dicomizador\" accion=\"activar\"/>"
// "<permiso namespace=\"oftalmologia\" id=\"vistaoftal\" accion=\"activar\"/>"
// "<permiso namespace=\"oftalmologia.vistaoftal\" id=\"Marcado del arbol de venas\" accion=\"activar\"/>"
// "<permiso namespace=\"oftalmologia.vistaoftal\" id=\"Marcado de Oftalmologia\" accion=\"activar\"/>"
// "<permiso namespace=\"oftalmologia.vistaoftal\" id=\"CoreMarcado\" accion=\"activar\"/>"
// "<permiso namespace=\"oftalmologia.vistaoftal\" id=\"Pegado de imagenes de la serie\" accion=\"desactivar\"/>"
// "<permiso namespace=\"oftalmologia.vistaoftal\" id=\"CoreAnotacion\" accion=\"activar\"/>"
// "<permiso namespace=\"oftalmologia.vistaoftal\" id=\"CoreElevacion\" accion=\"desactivar\"/>"
// "<permiso namespace=\"oftalmologia.vistaoftal\" id=\"CoreVarita\" accion=\"desactivar\"/>"
// "<permiso namespace=\"oftalmologia.vistaoftal\" id=\"panel de herramientas\" accion=\"desactivar\"/>"
// "<permiso namespace=\"oftalmologia.vistaoftal\" id=\"guardar cambios\" accion=\"desactivar\"/>"
// "<permiso namespace=\"dermatologia\" id=\"dicomizador\" accion=\"activar\"/>"
// "<permiso namespace=\"dermatologia\" id=\"vistapasi\" accion=\"activar\"/>"
// "<permiso namespace=\"dermatologia.vistapasi\" id=\"CoreMarcado\" accion=\"desactivar\"/>"
// "<permiso namespace=\"dermatologia.vistapasi\" id=\"DermaAnonimizacion\" accion=\"desactivar\"/>"
// "<permiso namespace=\"dermatologia.vistapasi\" id=\"CoreNota\" accion=\"desactivar\"/>"
// "<permiso namespace=\"dermatologia.vistapasi\" id=\"CoreElevacion\" accion=\"desactivar\"/>"
// "<permiso namespace=\"dermatologia.vistapasi\" id=\"CoreVarita\" accion=\"desactivar\"/>"
// "<permiso namespace=\"dermatologia.vistapasi\" id=\"panel de herramientas pasi\" accion=\"activar\"/>"
// "<permiso namespace=\"dermatologia.vistapasi\" id=\"guardar cambios\" accion=\"desactivar\"/>"
// "</permisos>\n"
